Name:		tex-zfuzz
Version:	3.4.1
Release:	8%{?dist}
Summary:	Type-checker and LaTeX style for Z spec language
Group:		Applications/Engineering
License:	BSD
URL:		http://spivey.oriel.ox.ac.uk/mike/fuzz/
Source0:	http://spivey.oriel.ox.ac.uk/mike/fuzz/fuzz-%{version}.tgz
Source1:	http://spivey.oriel.ox.ac.uk/mike/fuzz/fuzzman.pdf
Source2:	http://spivey.oriel.ox.ac.uk/mike/fuzz/refcard.pdf
Source3:	http://spivey.oriel.ox.ac.uk/mike/fuzz/fuzzman-2up.pdf
Source4:	http://spivey.oriel.ox.ac.uk/mike/fuzz/refcard-2up.pdf
Source5:	http://spivey.oriel.ox.ac.uk/mike/fuzz/refcard-3up.pdf
# Add DESTDIR support to the makefile
Patch0 :	tex-zfuzz-20070911-destdir.patch
# Remove a superfluous (and wrong) prototype, and don't generate the unused
# input() and unput() functions
Patch1:		tex-zfuzz-3.4.1-zscan.patch

Requires:	tex(latex)
BuildRequires:	tex(latex), bison, flex
Requires(post): tex(tex)
Requires(postun): tex(tex)

# Ubuntu and Debian have a different package named "fuzz", which is
# better-known and Fedora may include someday, so the command is renamed as
# "zfuzz" per upstream (Mike Spivey) recommendation.  The package is named
# "tex-zfuzz", to follow Fedora naming conventions for TeX packages. The
# LaTeX style is still "fuzz", preserving an upstream request: "please don't
# rename the LaTeX style option, or existing documents will break."

# The package contains a few glyphs, but creating a separate font
# subpackage seemed unnecessary and confusing (it's the only package using
# them). Thus, it's been packaged as a single package, as upstream does.
# The LaTeX style and type-checker COULD be separately packaged, but that also
# seems pointless; they are intended to be used together.

# Dirs for LaTeX styles, metafont, .tfm (root/specific), *pk (root/specific):
%global _texmf_main %{_datadir}/texmf
%global texdir	%{_texmf_main}/tex/latex/%{name}
%global mfdir	%{_texmf_main}/metafont/%{name}
%global tfmdirr	%{_texmf_main}/fonts/tfm/%{name}
%global pkdirr	%{_texmf_main}/fonts/pk/%{name}
%global tfmdir	%{tfmdirr}/oxsz
%global pkdir	%{pkdirr}/oxsz

%description
This package (formerly named "fuzz") is a collection of tools that help
you to:
(1) format and print good-looking specifications in the Z ("zed") formal
    specification language using LaTeX (through a new LaTeX style), and
(2) check them for compliance with the Z scope and type rules.  It
    includes a few font definitions for Z’s special symbols.

This package is useful if you want to create formal specifications using
the Z specification language.  The Z language accepted is that of the Z
Reference Manual, second edition, which is not exactly the same as the Z
ISO standard (see http://www.cs.york.ac.uk/hise/cadiz/standard.html for
the differences).

Historically, this package was called "fuzz", but there is another
program ALSO called fuzz, so the command-line type-checker's has been
changed to "zfuzz".  The LaTeX style itself is still named "fuzz" (so
LaTeX documents will keep working).

%prep
%setup -q -n fuzz-%{version}
%patch0
%patch1

# The source for some documents are in ./doc as LaTeX, but as upstream says:
# "The fuzz manual and reference card are written with LaTeX 2.09.
# Good luck unearthing a copy of that if you want to reformat it."
cp -p %SOURCE1 .
cp -p %SOURCE2 .
cp -p %SOURCE3 .
cp -p %SOURCE4 .
cp -p %SOURCE5 .

# Fix the default path
sed -i 's!/usr/local/lib/!%{_datadir}/%{name}/!g' src/param.c

%build
# The "lib" is really shared data, so we'll put it in %%_datadir (/usr/share)
# instead of /usr/lib to meet the File Hierarchy Standard (FHS).
make %{?_smp_mflags} CFLAGS="%{optflags}" \
 BINDIR=%{_bindir} LIBDIR=%{_datadir}/%{name} \
 TEXDIR=%{texdir} MFDIR=%{mfdir}

# Generate docs and pregenerated .tfm/*pk files:
pushd tex
 for file in oxsz[1-9]*.mf
 do
  mktextfm --destdir `pwd` `basename $file .mf`
 done
 mktexpk --destdir `pwd` --mfmode / --bdpi 600 --mag 1+120/600 --dpi 720 oxsz10
 pdflatex example.tex
 # Run latex twice on the tutorial (to get the cross-references correct):
 pdflatex tut.tex
 pdflatex tut.tex
 mv example.tex example.pdf tut.pdf ..
popd

%check
make test

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_datadir}/%{name}
install -d %{buildroot}%{texdir}
install -d %{buildroot}%{mfdir}
install -d %{buildroot}%{tfmdir}
install -d %{buildroot}%{pkdir}

make install DESTDIR=%{buildroot} \
 BINDIR=%{_bindir} LIBDIR=%{_datadir}/%{name} \
 TEXDIR=%{texdir} MFDIR=%{mfdir} INSTALL="install -p"

(cd %{buildroot}%{_bindir} ; mv fuzz zfuzz)

# Install pre-built .tfm and *pk files (speeds use):
cp -p tex/*.tfm %{buildroot}%{tfmdir}
cp -p tex/*pk %{buildroot}%{pkdir}

# The "INSTALL" file includes the license text, so install as doc.
# TeX file installation follows the "info tds" rules of texlive-texmf.

%files
%{_bindir}/*
%{_datadir}/%{name}/
%{texdir}/
%{mfdir}/
%{tfmdirr}/
%{pkdirr}/
%doc INSTALL
%doc fuzzman.pdf
%doc refcard.pdf
%doc fuzzman-2up.pdf
%doc refcard-2up.pdf
%doc refcard-3up.pdf
%doc example.tex
%doc example.pdf
%doc tut.pdf

%post
mktexlsr >/dev/null 2>&1 || :

%postun
mktexlsr >/dev/null 2>&1 || :

%changelog
* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Feb  4 2013 Jerry James <loganjerry@gmail.com> - 3.4.1-4
- Fix FTBFS due to TeXLive 2012 not defining %%{_texmf_main}

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan  7 2012 Jerry James <loganjerry@gmail.com> - 3.4.1-2
- Rebuild for GCC 4.7

* Wed Jun 22 2011 Jerry James <loganjerry@gmail.com> - 3.4.1-1
- New upstream version
- Drop upstreamed ctype and read-decl patches
- Drop unnecessary spec file elements (BuildRoot, etc.)
- Add the zscan patch to eliminate compiler errors and warnings

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.20070914.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.20070913.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.20070912.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jul 10 2008 David A. Wheeler - 0-0.20070911.3
- New release number (for CVS submission)

* Mon Jun 30 2008 David A. Wheeler - 0-0.20070911.2
- Added more information to Changelog (combined due to rev number change)

* Sun Jun 29 2008 David A. Wheeler - 0-0.20070911.1
- Initial packaging.
- Did not name it "fuzz" because of conflict with other program named fuzz
- Handled reviewer comments https://bugzilla.redhat.com/show_bug.cgi?id=452559
- Named package as tex-zfuzz (per Fedora naming guidelines)
- Came to agreement on version/revision convention
- Depend on virtual packages tex(tex) and tex(latex) instead of specific pkgs
- Shortened comments and description
- Renamed patch file names to clarify what upstream version they apply to
- Fixed .spec so it can build even when it's already installed
- Summary and description don't repeat package name
- Patch error.c to eliminate compiler warning for undefined isupper/islower
- Simplified CFLAGS argument
- Patched so would compile on 64-bit
